/*
** qtest.c	Tests the high-level ident calls.
**
** Author: Pr Emanuelsson <pell@lysator.liu.se>, 28 March 1993
*/

#ifdef NeXT3
#  include <libc.h>
#endif

#include <errno.h>
#include <stdlib.h>
#include <unistd.h>
#include <stdio.h>
#include <sys/types.h>

#define IN_LIBIDENT_SRC
#include "sident.h"

/* #define GDB_SLEEP */  

int
main(int argc, char *argv[])
{
    IDENT *ident;

    chdir("/tmp");

    puts("Welcome to the other IDENT server tester, version 1.0\r\n\r");  

    puts("Testing ident_lookup...\r\n\r");
#ifdef GDB_SLEEP
    printf("Sleeping... run gdb attach %d\n",getpid() );  
#endif 
    fflush(stdout);
    
#ifdef GDB_SLEEP
    sleep(45) ; 
#endif 

    ident_set_authtype("KERBEROS_V4","/etc/leland/srvtab.ident") ; 

    puts("Testing USER-INTERACTION=NO... \r\n\r\n"); 
    if ( ident_set_authflag("USER-INTERACTION","NO" ) == IDENT_AUTH_OKAY ) { 
	ident = ident_lookup(fileno(stdin), 30);

        fflush(stdout);
	if (!ident)
	    perror("ident");

	printf("IDENT response is:\r\n");
	printf("   Responder_Port........ %d\r\n", ident->resp_port);
	printf("   Requestor_Port........ %d\r\n", ident->req_port);
	printf("   Opsys........ %s\r\n", ident->opsys ? ident->opsys : "<unknown>" );
	printf("   Charset...... %s\r\n",
	       ident->charset ? ident->charset : "<not specified>");
	printf("   Identifier... %s\r\n", ident->identifier);

	printf("   Result code.. %d :%s \r\n",ident->result_code,ident_err_txt[ident->result_code]); 
	if ( ident->result_code != IDENT_AUTH_OKAY ) { 
	    if ( ident_query_error("CAPABLITIES","USER-INTERACTION",ident )
		 == IDENT_AUTH_OKAY) { 
		printf( "USER-INTERACTION Capable\r\n") ; 
	    }
	    if ( ident_query_error("AUTH-MECH","KERBEROS_V4",ident ) 
		 == IDENT_AUTH_OKAY) {
		printf( "KERBEROS_V4 Authentication available\r\n") ; 
	    }
	} 
        printf("\r\n\r\n");

	ident_free(ident);
  
	fflush(stdout);


    } 

    puts("Testing USER-INTERACTION=YES... \r\n\r\n"); 
    if ( ident_set_authflag("USER-INTERACTION","YES" ) == IDENT_AUTH_OKAY ) { 
	ident = ident_lookup(fileno(stdin), 30);

        fflush(stdout);
	if (!ident)
	    perror("ident");

	printf("IDENT response is:\r\n");
	printf("   Responder_Port........ %d\r\n", ident->resp_port);
	printf("   Requestor_Port........ %d\r\n", ident->req_port);
	printf("   Opsys........ %s\r\n", ident->opsys? ident->opsys : "<unknown>");
	printf("   Charset...... %s\r\n",
	       ident->charset ? ident->charset : "<not specified>");
	printf("   Identifier... %s\r\n", ident->identifier);

	printf("   Result code.. %d :%s \r\n",ident->result_code,ident_err_txt[ident->result_code]); 
	if ( ident->result_code != IDENT_AUTH_OKAY ) { 
	    if ( ident_query_error("CAPABILITY","USER-INTERACTION",ident )
		 == IDENT_AUTH_OKAY) { 
		printf( "USER-INTERACTION Capable\r\n") ; 
	    }
	    if ( ident_query_error("AUTH-MECH","KERBEROS_V4",ident ) 
		 == IDENT_AUTH_OKAY) {
		printf( "KERBEROS_V4 Authentication available\r\n") ; 
	    }
	 
	}
        printf("\r\n\r\n");
	ident_free(ident);
	fflush(stdout);

    }

    puts("Testing... USERINTERACTION unspecified \r\n\r\n"); 
    ident = ident_lookup(fileno(stdin), 30);

    fflush(stdout);
    if (!ident)
	perror("ident");

    printf("IDENT response is:\r\n");
    printf("   Responder_Port........ %d\r\n", ident->resp_port);
    printf("   Requestor_Port........ %d\r\n", ident->req_port);
    printf("   Opsys........ %s\r\n", ident->opsys?ident->opsys: "<unknown>");
    printf("   Charset...... %s\r\n",
	   ident->charset ? ident->charset : "<not specified>");
    printf("   Identifier... %s\r\n", ident->identifier);

    printf("   Result code.. %d :%s \r\n",ident->result_code,
	   ident_err_txt[ident->result_code]); 
    if ( ident->result_code != IDENT_AUTH_OKAY ) { 
	if ( ident_query_error("CAPABLITIES","USER-INTERACTION",ident )
	     == IDENT_AUTH_OKAY) { 
	    printf( "USER-INTERACTION Capable\r\n") ; 
	}
	if ( ident_query_error("AUTH-MECH","KERBEROS_V4",ident ) 
	     == IDENT_AUTH_OKAY) {
	    printf( "KERBEROS_V4 Authentication available\r\n") ; 
	}
    } 
    printf("\r\n\r\n");

    ident_free(ident);
  
    fflush(stdout);

    puts("Testing... Kerberos v5\r\n\r\n");
    ident_set_authtype("GSSAPI",NULL);
    ident = ident_lookup(fileno(stdin), 30);

    fflush(stdout);
    if (!ident)
        perror("ident");

    printf("IDENT response is:\r\n");
    printf("   Responder_Port........ %d\r\n", ident->resp_port);
    printf("   Requestor_Port........ %d\r\n", ident->req_port);
    printf("   Opsys........ %s\r\n", ident->opsys?ident->opsys: "<unknown>");
    printf("   Charset...... %s\r\n",
	   ident->charset ? ident->charset : "<not specified>");
    printf("   Identifier... %s\r\n", ident->identifier);

    printf("   Result code.. %d :%s \r\n",ident->result_code,
	   ident_err_txt[ident->result_code]); 
    if ( ident->result_code != IDENT_AUTH_OKAY ) { 
	if ( ident_query_error("CAPABLITIES","USER-INTERACTION",ident )
	     == IDENT_AUTH_OKAY) { 
	    printf( "USER-INTERACTION Capable\r\n") ; 
	}
	if ( ident_query_error("AUTH-MECH","KERBEROS_V4",ident ) 
	     == IDENT_AUTH_OKAY) {
	    printf( "KERBEROS_V4 Authentication available\r\n") ; 
	}
    }
    printf("\r\n\r\n");

    ident_free(ident);
    exit(0);
}

