/** @file
 * Provides necessary glue in order to use pidentd kernel files.
 *
 * This file provides the glue necessary to use pident3.* k_os files with
 * S/Ident without any changes to the k_os files.
 *
 * $Id: pidentd.h,v 1.2 2002/10/29 00:52:15 eagle Exp $
 */ 

#ifndef PIDENTD_H
#define PIDENTD_H

#include <sys/types.h>
#include <netinet/in.h>

#ifndef SYS_SOCKET_H_INCLUDED
# define SYS_SOCKET_H_INCLUDED
# include <sys/socket.h>
#endif

#define NO_UID ((uid_t) -1)
#define NO_PID ((pid_t) -1)

#ifndef KERNEL_HELPER 
extern char *osinfo_build ; 
#endif

char *osinfo_get( char *osinfo_current) ; 

void *s_malloc( size_t size ) ; 
void s_free( void *ptr) ; 

char *s_strdup(const char *dup_string ) ; 

struct kernel
{
    /* Request parameters */
    struct sockaddr_in local;
    struct sockaddr_in remote;

    /* Result parameters */
    
    int status;
    uid_t euid;
    uid_t ruid;

    pid_t pid;
    char *cmd;
    char *argv;
};

extern int kernel_threads;
extern int kernel_buffers;
extern int kernel_attempts;

extern struct kernel *kernel_alloc(void);
extern void kernel_free(struct kernel *kp);

extern int kernel_init(void);
extern void kernel_query(struct kernel *kp);


/*
** Operating system specific kernel access functions
*/
extern int ka_init(void);
extern int ka_open(void **misc);
extern int ka_lookup(void *misc, struct kernel *kp);

#endif /* PIDENTD_H */
